@@ -1,20 +1,23 @@
 package Pithub;
 our $AUTHORITY = 'cpan:PLU';
-our $VERSION = '0.01038';
 # ABSTRACT: Github v3 API
 
 use Moo;
-use Pithub::Events;
-use Pithub::Gists;
-use Pithub::GitData;
-use Pithub::Issues;
-use Pithub::Orgs;
-use Pithub::PullRequests;
-use Pithub::Repos;
-use Pithub::Search;
-use Pithub::SearchV3;
-use Pithub::Users;
-use Carp qw( croak );
+
+our $VERSION = '0.01039';
+
+use Carp                 qw( croak );
+use Pithub::Events       ();
+use Pithub::Gists        ();
+use Pithub::GitData      ();
+use Pithub::Issues       ();
+use Pithub::Orgs         ();
+use Pithub::PullRequests ();
+use Pithub::Repos        ();
+use Pithub::Search       ();
+use Pithub::SearchV3     ();
+use Pithub::Users        ();
+
 extends 'Pithub::Base';
 
 
@@ -37,48 +40,48 @@ sub _search_class {
     _validate_search_api($search_api);
 
     return $search_api eq 'legacy'
-        ? 'Pithub::Search'
-        : 'Pithub::SearchV3';
+        ? Pithub::Search::
+        : Pithub::SearchV3::;
 }
 
 
 sub events {
-    return shift->_create_instance('Pithub::Events', @_);
+    return shift->_create_instance(Pithub::Events::, @_);
 }
 
 
 sub gists {
-    return shift->_create_instance('Pithub::Gists', @_);
+    return shift->_create_instance(Pithub::Gists::, @_);
 }
 
 
 sub git_data {
-    return shift->_create_instance('Pithub::GitData', @_);
+    return shift->_create_instance(Pithub::GitData::, @_);
 }
 
 
 sub issues {
-    return shift->_create_instance('Pithub::Issues', @_);
+    return shift->_create_instance(Pithub::Issues::, @_);
 }
 
 
 sub markdown {
-    return shift->_create_instance('Pithub::Markdown', @_);
+    return shift->_create_instance(Pithub::Markdown::, @_);
 }
 
 
 sub orgs {
-    return shift->_create_instance('Pithub::Orgs', @_);
+    return shift->_create_instance(Pithub::Orgs::, @_);
 }
 
 
 sub pull_requests {
-    return shift->_create_instance('Pithub::PullRequests', @_);
+    return shift->_create_instance(Pithub::PullRequests::, @_);
 }
 
 
 sub repos {
-    return shift->_create_instance('Pithub::Repos', @_);
+    return shift->_create_instance(Pithub::Repos::, @_);
 }
 
 
@@ -94,7 +97,7 @@ sub search {
 
 
 sub users {
-    return shift->_create_instance('Pithub::Users', @_);
+    return shift->_create_instance(Pithub::Users::, @_);
 }
 
 
@@ -112,7 +115,7 @@ Pithub - Github v3 API
 
 =head1 VERSION
 
-version 0.01038
+version 0.01039
 
 =head1 SYNOPSIS
 
@@ -120,21 +123,21 @@ version 0.01038
 
     my $p = Pithub->new;
     # my $p = Pithub->new(utf8 => 0); # enable compatibility options for version 0.01029 or lower
-    my $result = $p->repos->get( user => 'plu', repo => 'Pithub' );
+    my $repo = $p->repos->get( user => 'plu', repo => 'Pithub' );
 
-    # $result->content is either an arrayref or an hashref
+    # $repo->content is either an arrayref or an hashref
     # depending on the API call that has been made
-    printf "%s\n", $result->content->{html_url};     # prints https://github.com/plu/Pithub
-    printf "%s\n", $result->content->{clone_url};    # prints https://github.com/plu/Pithub.git
+    printf "%s\n", $repo->content->{html_url};     # prints https://github.com/plu/Pithub
+    printf "%s\n", $repo->content->{clone_url};    # prints https://github.com/plu/Pithub.git
 
     # if the result is an arrayref, you can use the result iterator
-    my $result = $p->repos->list( user => 'plu' );
-    while ( my $row = $result->next ) {
+    my $repos = $p->repos->list( user => 'plu' );
+    while ( my $row = $repos->next ) {
         printf "%s\n", $row->{name};
     }
 
     # Connect to your local GitHub Enterprise instance
-    my $p = Pithub->new(
+    my $ghe_p = Pithub->new(
         api_uri => 'https://github.yourdomain.com/api/v3/'
     );
 
@@ -148,6 +151,24 @@ version 0.01038
     $pit->repos->get;
     $pit->repos->commits->list;
 
+    # Use a caching UserAgent
+    use CHI                    ();
+    use Pithub::Repos          ();
+    use WWW::Mechanize::Cached ();
+
+    my $cache = CHI->new(
+        driver   => 'File',
+        root_dir => '/tmp/pithub-example'
+    );
+
+    my $mech = WWW::Mechanize::Cached->new( cache => $cache );
+
+    my $cached_pithub = Pithub::Repos->new(
+        auto_pagination => 1,
+        per_page        => 100,
+        ua              => $mech,
+    );
+
 =head1 DESCRIPTION
 
 L<Pithub> (B<P>erl + GB<ithub>) provides a set of modules to access the
